"""Useful clients for commonly accessed APIs/services"""

from .google_photos import GooglePhotosClient
from .spotify import SpotifyClient
from .truelayer import TrueLayerClient
from .monzo import MonzoClient
